@@ -1,6 +1,8 @@
 import hy
-from dasy.compiler import compile
+from hy import read
+from dasy.compiler import compile, compile_file
 from dasy.main import main
+from dasy.parser.output import generate_external_interface_output
 from .parser import parse
 from .parser.parse import parse_src, parse_node
 
