@@ -1,9 +1,22 @@
+from vyper.compiler import compile_code
 from vyper.compiler.phases import CompilerData as VyperCompilerData
-from vyper.compiler.output import build_abi_output, build_asm_output, build_bytecode_runtime_output, build_external_interface_output, build_interface_output, build_ir_output, build_ir_runtime_output, build_layout_output, build_opcodes_output
+from pathlib import Path
+from vyper.compiler.output import (
+    build_abi_output,
+    build_asm_output,
+    build_bytecode_runtime_output,
+    build_external_interface_output,
+    build_interface_output,
+    build_ir_output,
+    build_ir_runtime_output,
+    build_layout_output,
+    build_opcodes_output,
+)
 from dasy.parser import parse_src
+from dasy.parser.utils import filename_to_contract_name
+
 
 class CompilerData(VyperCompilerData):
-
     def __init__(self, *args, **kwargs):
         VyperCompilerData.__init__(self, *args, **kwargs)
 
@@ -60,12 +73,11 @@ class CompilerData(VyperCompilerData):
         return build_layout_output(self)
 
 
-
-def generate_compiler_data(src: str) -> CompilerData:
+def generate_compiler_data(src: str, name="DasyContract") -> CompilerData:
     ast = parse_src(src)
     data = CompilerData(
         "",
-        ast.name,
+        ast.name or name,
         None,
         source_id=0,
     )
@@ -73,9 +85,20 @@ def generate_compiler_data(src: str) -> CompilerData:
     return data
 
 
-def compile(src: str, include_abi=True) -> CompilerData:
-    data = generate_compiler_data(src)
+def compile(src: str, name="DasyContract", include_abi=True) -> CompilerData:
+    data = generate_compiler_data(src, name)
     return data
 
+def compile_file(filepath: str) -> CompilerData:
+    path = Path(filepath)
+    name = path.stem
+    # name = ''.join(x.capitalize() for x in name.split('_'))
+    with path.open() as f:
+        src = f.read()
+        if filepath.endswith('.vy'):
+            return CompilerData(src, contract_name=filename_to_contract_name(filepath))
+        return compile(src, name=name)
+
+
 def generate_abi(src: str) -> list:
     return compile(src).abi
